[![Actions Status](https://github.com/qtoggle/qtoggleserver/workflows/Release/badge.svg)](https://github.com/qtoggle/qtoggleserver/actions)
[![Join us on https://gitter.im/qtoggle/community](https://badges.gitter.im/qtoggle/community.png)](https://gitter.im/qtoggle/community?utm_source=badge&utm_medium=badge&utm_content=badge)

Join us on [Facebook](http://facebook.com/qtoggle).

---


**qToggleServer** is a fully fledged [qToggle](https://github.com/qtoggle/docs) implementation written in Python.

Check out the [Getting Started](https://github.com/qtoggle/qtoggleserver/wiki/Getting-Started) wiki page to install and get started with qToggleServer.
